Module codegen

Module codegen 

Intermediate code generation from the AST.

Enums

CodegenError
Error while generating an intermediate code from the AST.
ParserOrCodegenError
Represents either a parser error or a codegen error.

Functions

codegen_ast
Generates intermediate code from the AST.
codegen_str
Generates intermediate code for the given SQL.