Module vm

Module vm 

The executor virtual machine, its registers and errors.

See VirtualMachine and Register.

Structs

InsertDef
An abstract definition of an insert statement.
InsertRow
A row of values to insert.
RegisterIndex
An index that can be used to access a specific register.
TableDef
An abstract definition of a create table statement.
TableIndex
An index that can be used as a reference to a table.
VirtualMachine
Executor of an SQL query.

Enums

ExecutionError
Register
A register in the executor VM.
RuntimeError
All possible errors handled during execution.